# Copyright (C) 1998-2003,2009 by the Free Software Foundation, Inc.
#                    2005 Lionel Elie Mamane <lionel@mamane.lu>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Author: Bernhard Reiter <bernhard@gnu.org>
# Changed by Lionel Elie Mamane December 2005 from version on
# http://ftp.intevation.de/users/bernhard/mailman/mailman-2.1.4-avoid-headerfolding-python21.diff
# to use clone/children_maxheaderlen trick instead of _write_headers/mangle_from_
# Changed by Mark Sapiro May 2009 to fix bug: messages with lines beginning
# with "From" are archived split into several messages.

"""Standard Mailman generator object.

A subclass of email.Generator which only folds long headers
in the top object level. 
This is needed because Mailman should leave the reveiced message parts alone.
Otherwise is might change subparts over which a signature was calculated,
breaking it while doing so.
"""

import email
import email.Generator

try:
    True, False
except NameError:
    True = 1
    False = 0


class Generator(email.Generator.Generator):
    """Generates output from a Message object tree, keeping signatures.

       Headers will by default _not_ be folded in attachments.
    """
    def __init__(self, outfp, mangle_from_=True,
                 maxheaderlen=78, children_maxheaderlen=0):
        email.Generator.Generator.__init__(self, outfp, mangle_from_=mangle_from_, maxheaderlen=maxheaderlen)
        self.__children_maxheaderlen = children_maxheaderlen

    def clone(self, fp):
        """Clone this generator with maxheaderlen set for children"""
        return self.__class__(fp, self._mangle_from_, self.__children_maxheaderlen, self.__children_maxheaderlen)

